==> v1.3.1.tar.gz: syncthingtray-1.3.1/fileitemactionplugin/translations/syncthingfileitemaction_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SyncthingDirActions</name>
    <message>
        <location filename="../syncthingdiractions.cpp" line="34"/>
        <source>Status: not available anymore</source>
        <translation>Status: nicht mehr verfügbar</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="43"/>
        <source>Directory info for %1</source>
        <translation>Verzeichnisinfo für %1</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="44"/>
        <source>Status: </source>
        <translation>Status: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="73"/>
        <source>Global: </source>
        <translation>Global: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="74"/>
        <source>Local: </source>
        <translation>Lokal: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="75"/>
        <source>Last scan time: </source>
        <translation>Letzter Scan: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="76"/>
        <source>Rescan interval: %1 seconds</source>
        <translation>Scanintervall: %1 Sekunden</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdiractions.cpp" line="81"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemAction</name>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="154"/>
        <source>Rescan selected items</source>
        <translation>Auswahl neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="173"/>
        <source>Rescan selected directories</source>
        <translation>Ausgewählte Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="186"/>
        <source>Resume selected directories</source>
        <translation>Ausgewählte verzeichnisse fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="156"/>
        <location filename="../syncthingfileitemaction.cpp" line="173"/>
        <location filename="../syncthingfileitemaction.cpp" line="204"/>
        <source>Rescan &quot;%1&quot;</source>
        <translation>&quot;%1&quot; neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="189"/>
        <source>Pause selected directories</source>
        <translation>Ausgewählte Verzeichnisse pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="204"/>
        <source>Rescan containing directories</source>
        <translation>Beinhaltendes Verzeichnis neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="217"/>
        <source>Resume containing directories</source>
        <translation>Beinhaltendes Verzeichnis fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="246"/>
        <source>Not a shared directory</source>
        <translation>Kein geteiltes Verzeichnis</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="186"/>
        <location filename="../syncthingfileitemaction.cpp" line="217"/>
        <source>Resume &quot;%1&quot;</source>
        <translation>&quot;%1&quot; fortsetzen (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="221"/>
        <source>Pause containing directories</source>
        <translation>Beinhaltendes Verzeichnis pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="189"/>
        <location filename="../syncthingfileitemaction.cpp" line="221"/>
        <source>Pause &quot;%1&quot;</source>
        <translation>&quot;%1&quot; pausieren (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <source>Use bright custom colors</source>
        <translation type="vanished">Helle Farben verwenden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="280"/>
        <source>Select Syncthing config ...</source>
        <translation>Syncthing-Konfiguration wählen ...</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="285"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemActionStaticData</name>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="84"/>
        <source>Syncthing connection error</source>
        <translation>Fehler beim Verbinden mit Syncthing</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="104"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="112"/>
        <source>Select Syncthing config file</source>
        <translation>Syncthing-Konfigurationsdatei auswählen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="138"/>
        <source>Syncthing config file can not be automatically located</source>
        <translation>Syncthing-Konfigurationsdatei kann nicht automatisch gefunden werden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="145"/>
        <source>Unable to load Syncthing config from &quot;%1&quot;</source>
        <translation>Fehler beim Laden der Syncthing-Konfiguration von &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="154"/>
        <source>Syncthing config from &quot;%1&quot; does not contain GUI address.</source>
        <translation>Die Syncthing-Konfiguration &quot;%1&quot; beinhaltet keine GUI-Adresse.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="166"/>
        <source>Enter API key</source>
        <translation>API-Schlüssel eingeben</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="166"/>
        <source>The selected config file does not contain an API key. Please enter the API key manually:</source>
        <translation>Die gewählte Konfiguration enthält keinen API-Schlüssel. Gib den API-Schlüssel manuell ein:</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="168"/>
        <source>No API key supplied for &quot;%1&quot;.</source>
        <translation>Kein API-Schlüssel für die Konfiguration &quot;%1&quot; angegeben.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="127"/>
        <source>(still using config from &quot;%1&quot;)</source>
        <translation>(verwende weiterhin &quot;%1&quot;)</translation>
    </message>
</context>
<context>
    <name>SyncthingMenuAction</name>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="68"/>
        <source>Syncthing</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="79"/>
        <source>Syncthing - connecting</source>
        <translation>Syncthing - verbinde</translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="81"/>
        <source>Syncthing - not connected</source>
        <translation>Syncthing - nicht verbunden</translation>
    </message>
</context>
</TS>

==> v1.6.2.tar.gz: syncthingtray-1.6.2/fileitemactionplugin/translations/syncthingfileitemaction_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SyncthingDirActions</name>
    <message>
        <location filename="../syncthingdiractions.cpp" line="34"/>
        <source>Status: not available anymore</source>
        <translation>Status: nicht mehr verfügbar</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="43"/>
        <source>Folder info for %1</source>
        <translation>Ordnerinfo für %1</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="44"/>
        <source>Status: </source>
        <translation>Status: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="73"/>
        <source>Global: </source>
        <translation>Global: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="74"/>
        <source>Local: </source>
        <translation>Lokal: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="75"/>
        <source>Last scan time: </source>
        <translation>Letzter Scan: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="76"/>
        <source>Rescan interval: %1 seconds</source>
        <translation>Scanintervall: %1 Sekunden</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdiractions.cpp" line="81"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemAction</name>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="153"/>
        <source>Rescan selected items</source>
        <translation>Auswahl neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="172"/>
        <source>Rescan selected folders</source>
        <translation>Ausgewählte Ordner neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="185"/>
        <source>Resume selected folders</source>
        <translation>Ausgewählte Ordner fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="155"/>
        <location filename="../syncthingfileitemaction.cpp" line="172"/>
        <location filename="../syncthingfileitemaction.cpp" line="203"/>
        <source>Rescan &quot;%1&quot;</source>
        <translation>&quot;%1&quot; neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="188"/>
        <source>Pause selected folders</source>
        <translation>Ausgewählte Ordner pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="203"/>
        <source>Rescan containing folders</source>
        <translation>Beinhaltenden Ordner neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="215"/>
        <source>Resume containing folders</source>
        <translation>Beinhaltende Ordner fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="243"/>
        <source>Not a shared directory</source>
        <translation>Kein geteilter Ordner</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="185"/>
        <location filename="../syncthingfileitemaction.cpp" line="215"/>
        <source>Resume &quot;%1&quot;</source>
        <translation>&quot;%1&quot; fortsetzen (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="219"/>
        <source>Pause containing folders</source>
        <translation>Beinhaltenden Ordner pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="188"/>
        <location filename="../syncthingfileitemaction.cpp" line="219"/>
        <source>Pause &quot;%1&quot;</source>
        <translation>&quot;%1&quot; pausieren (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <source>Use bright custom colors</source>
        <translation type="vanished">Helle Farben verwenden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="277"/>
        <source>Select Syncthing config ...</source>
        <translation>Syncthing-Konfiguration wählen ...</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="282"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemActionStaticData</name>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="84"/>
        <source>Syncthing connection error</source>
        <translation>Fehler beim Verbinden mit Syncthing</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="104"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="112"/>
        <source>Select Syncthing config file</source>
        <translation>Syncthing-Konfigurationsdatei auswählen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="138"/>
        <source>Syncthing config file can not be automatically located</source>
        <translation>Syncthing-Konfigurationsdatei kann nicht automatisch gefunden werden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="145"/>
        <source>Unable to load Syncthing config from &quot;%1&quot;</source>
        <translation>Fehler beim Laden der Syncthing-Konfiguration von &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="154"/>
        <source>Syncthing config from &quot;%1&quot; does not contain GUI address.</source>
        <translation>Die Syncthing-Konfiguration &quot;%1&quot; beinhaltet keine GUI-Adresse.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="166"/>
        <source>Enter API key</source>
        <translation>API-Schlüssel eingeben</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="166"/>
        <source>The selected config file does not contain an API key. Please enter the API key manually:</source>
        <translation>Die gewählte Konfiguration enthält keinen API-Schlüssel. Gib den API-Schlüssel manuell ein:</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="168"/>
        <source>No API key supplied for &quot;%1&quot;.</source>
        <translation>Kein API-Schlüssel für die Konfiguration &quot;%1&quot; angegeben.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="127"/>
        <source>(still using config from &quot;%1&quot;)</source>
        <translation>(verwende weiterhin &quot;%1&quot;)</translation>
    </message>
</context>
<context>
    <name>SyncthingMenuAction</name>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="69"/>
        <source>Syncthing</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="80"/>
        <source>Syncthing - connecting</source>
        <translation>Syncthing - verbinde</translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="82"/>
        <source>Syncthing - not connected</source>
        <translation>Syncthing - nicht verbunden</translation>
    </message>
</context>
</TS>
